#!/bin/bash

#if test file list set
testfile="${ASCDS_WORK_PATH}/smoke.${LOGNAME}/smoketests.txt"
if [ ! \( -r ${testfile} \) ]; then
   echo " FAILED: no tests specified "
   exit 0
fi

# get number of tests in file list- expect tests to end in 'smoke###.sh' 
CNT=`grep "smoke[0-9][0-9][0-9].sh" ${testfile} | grep -c -v "#"`

if [ "$CNT" = "0" ]; then
   echo " FAILED: the test file contains no entries"
   exit 0
elif [ "$CNT" = "1" ]; then
   echo " Requested test suite includes $CNT test" 
else
   echo " Requested test suite includes $CNT tests" 
fi


# move into the smoke test directory 
cd smoke/bin
###cd ${ASCDS_INSTALL}/test/smoke/bin

NDX=1
FAILURES=0

# if CIAO_DEBUG env var is 0 - only display pass/fail
#                          1 - display diffs in line
#                          2 - display diffs at end 
ERRLOG=""
if [ "${CIAO_DEBUG}" = "2" ]
then
   ERRLOG="${ASCDS_WORK_PATH}/smoke.${LOGNAME}/.diff_logs"  
   if [ -r ${ERRLOG} ]
   then
      \rm ${ERRLOG}
   fi
fi

# loop through specified tests and run them 

exec < ${testfile}
while read LINE
do
   if echo "$LINE" | grep -v "#"  >/dev/null
   then 
      printf "   [${NDX}/${CNT}] " 
      sh $LINE
      if [ $? -ne 0 ]
      then
         # test failed- handle logging based on CIAO_DEBUG setting   
         FAILURES=`expr $FAILURES + 1`
	 LINE="`basename $LINE`"
         ERRFILE=`echo $LINE | sed -e 's/\.sh/\/diff\.log/g'`
         if [ "${ERRLOG}" != "" ] 
         then 
            echo "   Review ${ASCDS_WORK_PATH}/smoke.${LOGNAME}/${ERRFILE} for details" >> ${ERRLOG}
         elif [ "${CIAO_DEBUG}" != "0" ]
         then 
            echo "         Review ${ASCDS_WORK_PATH}/smoke.${LOGNAME}/${ERRFILE} for details"
         fi 
      fi 
      NDX=`expr $NDX + 1`
   fi 
done 

if [ $FAILURES -eq 0 ]
then
   echo " All smoke tests PASSED."
else 
   echo " $FAILURES out of $CNT smoke tests FAILED."  

   if [ "${ERRLOG}" != "" ] 
   then 
      cat ${ERRLOG}
      \rm  ${ERRLOG}
   fi 
   echo ""
   echo "       !! CIAO MAY HAVE FAILED TO INSTALL PROPERLY !!"
   echo " Please check http://cxc.harvard.edu/ciao4.8/bugs/smoke.html"
   echo " for a list of known issues before contacting the Help Desk."
   echo ""
fi 





